@@ -28,11 +28,12 @@ logger = getLogger('mortar_rdb')
 def registerSession(url=None,
                     name=u'',
                     engine=None,
-                    echo=False,
+                    echo=None,
                     transactional=True,
                     scoped=True,
                     config=None,
-                    extension=None):
+                    extension=None,
+                    twophase=True):
     """
     Create a :class:`~sqlalchemy.orm.session.Session` class and
     register it for later use.
@@ -75,6 +76,11 @@ def registerSession(url=None,
       or sequence of :class:`~sqlalchemy.orm.interfaces.SessionExtension`
       objects to be used with the session that is registered.
 
+    :param twophase: By default two-phase transactions are used where
+      supported by the underlying database. Where this causes problems,
+      single-phase transactions can be used for all engines by passing this
+      parameter as `False`.
+
     """
     if (engine and url) or not (engine or url):
         raise TypeError('Must specify engine or url, but not both')
@@ -93,9 +99,11 @@ def registerSession(url=None,
     if config is not None:
         validate(engine,config)
 
+    url = str(engine.url)
+    if engine.url.password is not None:
+        url = url.replace(engine.url.password,'<password>')
     logger.info('Registering session for %r with name %r',
-                str(engine.url),
-                name)
+                url,name)
 
     params = dict(
             bind = engine,
@@ -118,7 +126,7 @@ def registerSession(url=None,
             # whether or not we use the ORM.
             initial_state=STATUS_CHANGED,
             ))
-        if engine.dialect.name in ('postgresql', 'mysql'):
+        if twophase and engine.dialect.name in ('postgresql', 'mysql'):
             params['twophase']=True
 
     if extensions:
